==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/DOCUMENTENTITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DOCUMENTENTITYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DOCUMENTENTITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="document" type="{http://schemas.datastream.net/MP_fields}CODE30_Type" />
 *       &lt;attribute name="rentity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="code" type="{http://schemas.datastream.net/MP_fields}CODE50_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DOCUMENTENTITYID_Type")
public class DOCUMENTENTITYID_Type {

    @XmlAttribute(name = "document")
    protected String document;
    @XmlAttribute(name = "rentity")
    protected String rentity;
    @XmlAttribute(name = "code")
    protected String code;

    /**
     * Gets the value of the document property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocument() {
        return document;
    }

    /**
     * Sets the value of the document property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocument(String value) {
        this.document = value;
    }

    /**
     * Gets the value of the rentity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRentity() {
        return rentity;
    }

    /**
     * Sets the value of the rentity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRentity(String value) {
        this.rentity = value;
    }

    /**
     * Gets the value of the code property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCode() {
        return code;
    }

    /**
     * Sets the value of the code property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCode(String value) {
        this.code = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/DOCUMENTENTITYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DOCUMENTENTITYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DOCUMENTENTITYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="document" type="{http://schemas.datastream.net/MP_fields}CODE30_Type" />
 *       &lt;attribute name="rentity" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="code" type="{http://schemas.datastream.net/MP_fields}CODE50_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DOCUMENTENTITYID_Type")
public class DOCUMENTENTITYID_Type {

    @XmlAttribute(name = "document")
    protected String document;
    @XmlAttribute(name = "rentity")
    protected String rentity;
    @XmlAttribute(name = "code")
    protected String code;

    /**
     * Obtient la valeur de la propriété document.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDocument() {
        return document;
    }

    /**
     * Définit la valeur de la propriété document.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDocument(String value) {
        this.document = value;
    }

    /**
     * Obtient la valeur de la propriété rentity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRentity() {
        return rentity;
    }

    /**
     * Définit la valeur de la propriété rentity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRentity(String value) {
        this.rentity = value;
    }

    /**
     * Obtient la valeur de la propriété code.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCode() {
        return code;
    }

    /**
     * Définit la valeur de la propriété code.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCode(String value) {
        this.code = value;
    }

}
